import {
  IonContent,
  IonHeader,
  IonItem,
  IonLabel,
  IonList,
  IonModal,
  IonRadio,
  IonRadioGroup,
  IonTitle,
} from '@ionic/react';
import React from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { mapActions, MapState } from '../../store/map';
import { tileProviders } from './tile';

const TileServerChooserDialog: React.FC<{}> = () => {
  
  const tileProvider = useSelector(
    (state: { map: MapState }) => state.map.scope.tileProvider
  ) as keyof typeof tileProviders;

  const dispatch = useDispatch();

  const changeHandler = (event: any) => {
    dispatch(mapActions.setTileProvider(event.detail.value));
  };

  return (
    <IonModal trigger='open-TileServerChooser'>
      <IonHeader>
        <IonTitle>Select your map</IonTitle>
      </IonHeader>
      <IonContent>
        <IonList>
          <IonRadioGroup value={tileProvider} onIonChange={changeHandler}>
            {Object.keys(tileProviders).map((provider) => {
              return (
                <IonItem key={provider}>
                  <IonLabel> {tileProviders[provider].name}</IonLabel>
                  <IonRadio slot='start' value={provider} />
                </IonItem>
              );
            })}
          </IonRadioGroup>
        </IonList>
      </IonContent>
    </IonModal>
  );
};

export default TileServerChooserDialog;
